@@ -68,7 +68,7 @@ class Color:
 
     def show(self):
         r, g, b = self.__repr__()
-        print(f"\x1b[38;2;{int(r)};{int(g)};{int(b)}--- COLOR ---\x1b[0m")
+        print(f"\x1b[38;2;{int(r)};{int(g)};{int(b)}m--- COLOR ---\x1b[0m")
 
     @staticmethod
     def scale_rgb(rgb):
