@@ -15,4 +15,4 @@ print(f"Representation of red in HSL : {(h*360, s*100, l*100)}")
 # Show the color in the Terminal
 red.show()
 
-cG.credit()
+cG.credits()
